const COMPARATORS = {
    asc: (x, y) => x > y,
    desc: (x, y) => x < y,
};
export function purryOrderRules(func, inputArgs) {
    const [dataOrRule, ...rules] = inputArgs;
    if (!isOrderRule(dataOrRule)) {
        const compareFn = orderRuleComparer(...rules);
        return func(dataOrRule, compareFn);
    }
    const compareFn = orderRuleComparer(dataOrRule, ...rules);
    return (data) => func(data, compareFn);
}
export function purryOrderRulesWithArgument(func, [first, second, ...rest]) {
    let arg;
    let argRemoved;
    if (isOrderRule(second)) {
        arg = first;
        argRemoved = [second, ...rest];
    }
    else {
        arg = second;
        argRemoved = [first, ...rest];
    }
    return purryOrderRules((...args) => func(...args, arg), argRemoved);
}
function orderRuleComparer(primaryRule, secondaryRule, ...otherRules) {
    const projector = typeof primaryRule === "function" ? primaryRule : primaryRule[0];
    const direction = typeof primaryRule === "function" ? "asc" : primaryRule[1];
    const { [direction]: comparator } = COMPARATORS;
    const nextComparer = secondaryRule === undefined
        ? undefined
        : orderRuleComparer(secondaryRule, ...otherRules);
    return (a, b) => {
        const projectedA = projector(a);
        const projectedB = projector(b);
        if (comparator(projectedA, projectedB)) {
            return 1;
        }
        if (comparator(projectedB, projectedA)) {
            return -1;
        }
        return nextComparer?.(a, b) ?? 0;
    };
}
function isOrderRule(x) {
    if (isProjection(x)) {
        return true;
    }
    if (typeof x !== "object" || !Array.isArray(x)) {
        return false;
    }
    const [maybeProjection, maybeDirection, ...rest] = x;
    return (isProjection(maybeProjection) &&
        typeof maybeDirection === "string" &&
        maybeDirection in COMPARATORS &&
        rest.length === 0);
}
const isProjection = (x) => typeof x === "function" && x.length === 1;
