import { purry } from "./purry";
export function sample(...args) {
    return purry(sampleImplementation, args);
}
function sampleImplementation(data, sampleSize) {
    if (sampleSize < 0) {
        throw new RangeError(`sampleSize must cannot be negative: ${sampleSize}`);
    }
    if (!Number.isInteger(sampleSize)) {
        throw new TypeError(`sampleSize must be an integer: ${sampleSize}`);
    }
    if (sampleSize >= data.length) {
        return data.slice();
    }
    if (sampleSize === 0) {
        return [];
    }
    const actualSampleSize = Math.min(sampleSize, data.length - sampleSize);
    const sampleIndices = new Set();
    while (sampleIndices.size < actualSampleSize) {
        const randomIndex = Math.floor(Math.random() * data.length);
        sampleIndices.add(randomIndex);
    }
    if (sampleSize === actualSampleSize) {
        return Array.from(sampleIndices)
            .sort((a, b) => a - b)
            .map((index) => data[index]);
    }
    return data.filter((_, index) => !sampleIndices.has(index));
}
